==========
pythermica
==========


.. image:: https://img.shields.io/pypi/v/pythermica.svg
        :target: https://pypi.python.org/pypi/pythermica
.. 
  .. image:: https://img.shields.io/travis/antoinetavant/pythermica.svg
        :target: https://travis-ci.com/antoinetavant/pythermica

.. image:: https://readthedocs.org/projects/pythermica/badge/?version=latest
        :target: https://pythermica.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

.. image:: https://raw.githubusercontent.com/astronautix/pythermica/main/coverage.svg
        :target: https://raw.githubusercontent.com/astronautix/pythermica/main/coverage.svg
        :alt: Coverage percent
 

Post processing for Thermica simulation results


* Free software: GNU General Public License v3
* Documentation: https://pythermica.readthedocs.io.


Features
--------
Allows the automatic and deep analyses of Systema-Thermica results:

* Analyse the nwk files to asses the Conductive and Radiative coupling coefficients
* Analyse the simulation results, like Temperature, internal dissipation, flexes, etc.
* Generate automaticaly the relevant figures

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
